#  Copyright 2025 European Union
#  Author: Bulgheroni Antonio (antonio.bulgheroni@ec.europa.eu)
#  SPDX-License-Identifier: EUPL-1.2
__version__ = '1.0.0-rc.5'
__author__ = 'Antonio Bulgheroni'
__author_email__ = 'antonio.bulgheroni@ec.europa.eu'
